import {
  select,
  scaleLinear,
  extent,
  range,
  domain,
} from 'd3';

import { axis } from './axis';

export function scatterPlot(container, data) {
  const margin = {
    left: 60,
    right: 40,
    top: 30,
    bottom: 50,
  };
  const width = innerWidth;
  const height = innerHeight;

  const xValue = (d) => d.petal_width;
  const yValue = (d) => d.petal_length;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'rgb(0,100,110)');

  svg
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('r', 7)
    .attr('opacity', 600 / 1000)
    .attr('fill', `hsl(${Math.random() * 360},60%,80%)`)
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)));

  svg.call(axis, { xScale, yScale });
}
